@@ -1,6 +1,7 @@
 """ Helper functions to communicate with replication servers.
 """
 
+import requests
 import urllib.request as urlrequest
 import datetime as dt
 from collections import namedtuple
@@ -26,6 +27,7 @@ class ReplicationServer:
     def __init__(self, url, diff_type='osc.gz'):
         self.baseurl = url
         self.diff_type = diff_type
+        self.session = requests.Session()
 
     def make_request(self, url):
         headers = {"User-Agent" : "pyosmium/{}".format(version.pyosmium_release)}
@@ -48,7 +50,10 @@ class ReplicationServer:
                 svr = ReplicationServer()
                 svr.open_url = my_open_url
         """
-        return urlrequest.urlopen(url)
+        headers = dict()
+        for h in url.header_items():
+            headers[h[0]] = h[1]
+        return self.session.get(url.get_full_url(), headers=headers, stream=True)
 
     def collect_diffs(self, start_id, max_size=1024):
         """ Create a MergeInputReader and download diffs starting with sequence
@@ -292,8 +297,14 @@ class ReplicationServer:
 
             ts = None
             seq = None
-            line = response.readline()
-            while line:
+            if hasattr(response, 'iter_lines'):
+                # generated by requests
+                get_line = response.iter_lines
+            else:
+                # generated by urllib.request
+                get_line = response.readline
+
+            for line in get_line():
                 line = line.decode('utf-8')
                 if '#' in line:
                     line = line[0:line.index('#')]
@@ -311,7 +322,6 @@ class ReplicationServer:
                         except ValueError:
                             break
                         ts = ts.replace(tzinfo=dt.timezone.utc)
-                line = response.readline()
 
             if ts is not None and seq is not None:
                 return OsmosisState(sequence=seq, timestamp=ts)
@@ -324,7 +334,13 @@ class ReplicationServer:
             (or :code:`urllib2.HTTPError` in python2)
             if the file cannot be downloaded.
         """
-        return self.open_url(self.make_request(self.get_diff_url(seq))).read()
+        resp = self.open_url(self.make_request(self.get_diff_url(seq)))
+        if hasattr(resp, 'content'):
+            # generated by requests
+            return resp.content
+        else:
+            # generated by urllib.request
+            return resp.read()
 
 
     def get_state_url(self, seq):
