@@ -16,6 +16,13 @@ try:
 except:
     from io import StringIO
 
+from requests import Session
+
+try:
+    import http.cookiejar as cookiejarlib
+except ImportError:
+    import cookielib as cookiejarlib
+
 try:
     from urllib.error import URLError
 except ImportError:
@@ -36,6 +43,14 @@ class Capturing(list):
         del self._stringio    # free up some memory
         sys.stdout = self._stdout
 
+class RequestsResponses(BytesIO):
+
+    def __init__(self, bytes):
+       super(RequestsResponses, self).__init__(bytes)
+       self.content = bytes
+
+    def iter_lines(self):
+       return self.readlines()
 
 class TestPyosmiumGetChanges(unittest.TestCase):
 
@@ -44,11 +59,15 @@ class TestPyosmiumGetChanges(unittest.TestCase):
                                            "../../tools/pyosmium-get-changes"))
         self.url_mock = MagicMock()
         self.urls = dict()
-        self.url_mock.side_effect = lambda url : self.urls[url.get_full_url()]
-        self.script['rserv'].urlrequest.urlopen = self.url_mock
+        self.url_mock.side_effect = lambda url,data=None,timeout=None : self.urls[url.get_full_url()]
+        self.script['rserv'].urlrequest.OpenerDirector.open = self.url_mock
+
+        self.urlreq_mock = MagicMock()
+        self.urlreq_mock.side_effect = lambda url,**kw : self.urls[url]
+        self.script['rserv'].requests.Session.get = self.urlreq_mock
 
     def url(self, url, result):
-        self.urls[url] = BytesIO(dedent(result).encode())
+        self.urls[url] = RequestsResponses(dedent(result).encode())
 
     def main(self, *args):
         with Capturing() as output:
@@ -86,8 +105,8 @@ class TestPyosmiumGetChanges(unittest.TestCase):
         content = fd.read()
         try:
             assert_equals('454', content)
-            fd.close()
         finally:
+            fd.close()
             unlink(fname)
 
     def test_init_from_seq_file(self):
@@ -98,5 +117,32 @@ class TestPyosmiumGetChanges(unittest.TestCase):
         assert_equals(0, self.main('-f', fname))
         fd = open(fname, 'r')
         content = fd.read()
-        assert_equals('454', content)
+        try:
+            assert_equals('454', content)
+        finally:
+            fd.close()
+            unlink(fname)
 
+    def test_init_date_with_cookie(self):
+        self.url('https://planet.osm.org/replication/minute//state.txt',
+                 """\
+                    sequenceNumber=100
+                    timestamp=2017-08-26T11\:04\:02Z
+                 """)
+        self.url('https://planet.osm.org/replication/minute//000/000/000.state.txt',
+                 """\
+                    sequenceNumber=0
+                    timestamp=2016-08-26T11\:04\:02Z
+                 """)
+
+        with tempfile.NamedTemporaryFile(dir=tempfile.gettempdir(), suffix='.cookie', delete=False) as fd:
+            fname = fd.name
+        cookie_jar = cookiejarlib.MozillaCookieJar(fname)
+        cookie_jar.save()
+
+        try:
+            assert_equals(0, self.main('--cookie', fname, '-D', '2015-12-24T08:08:08Z'))
+            assert_equals(1, len(self.stdout))
+            assert_equals('1', self.stdout[0])
+        finally:
+            unlink(fname)
